"""
Setup the basic connection things
"""

#set the base url of the SPONGE-web API
api_url_base = 'https://exbio.wzw.tum.de/sponge-api/'

#set up the HTTP request headers the way the API docs describe
headers = {'Content-Type': 'application/json'}